.. mainf.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive._mainf package.



AutoArchive._mainf
==================

.. automodule:: AutoArchive._mainf
   :no-members:



Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   mainf.core



Modules
-------

icomponent
^^^^^^^^^^

.. automodule:: AutoArchive._mainf.icomponent




icomponent-ui
^^^^^^^^^^^^^

.. automodule:: AutoArchive._mainf.icomponent_ui



iinterface_accessor
^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._mainf.iinterface_accessor



imainf_context
^^^^^^^^^^^^^^

.. automodule:: AutoArchive._mainf.imainf_context



main
^^^^

.. automodule:: AutoArchive._mainf.main
